==> deluge_1.3.3.orig.tar.gz: deluge-1.3.3/deluge/_libtorrent.py <==
#
# _libtorrent.py
#
# Copyright (C) 2009 Andrew Resch <andrewresch@gmail.com>
#
# Deluge is free software.
#
# You may redistribute it and/or modify it under the terms of the
# GNU General Public License, as published by the Free Software
# Foundation; either version 3 of the License, or (at your option)
# any later version.
#
# deluge is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with deluge.    If not, write to:
# 	The Free Software Foundation, Inc.,
# 	51 Franklin Street, Fifth Floor
# 	Boston, MA  02110-1301, USA.
#
#    In addition, as a special exception, the copyright holders give
#    permission to link the code of portions of this program with the OpenSSL
#    library.
#    You must obey the GNU General Public License in all respects for all of
#    the code used other than OpenSSL. If you modify file(s) with this
#    exception, you may extend this exception to your version of the file(s),
#    but you are not obligated to do so. If you do not wish to do so, delete
#    this exception statement from your version. If you delete this exception
#    statement from all source files in the program, then also delete it here.
#
#

"""
This module is used to handle the importing of libtorrent.

We use this module to control what versions of libtorrent this version of Deluge
supports.

** Usage **

>>> from deluge._libtorrent import lt

"""

REQUIRED_VERSION = "0.14.9.0"

def check_version(LT):
    from deluge.common import VersionSplit
    if VersionSplit(lt.version) < VersionSplit(REQUIRED_VERSION):
        raise ImportError("This version of Deluge requires libtorrent >=%s!" % REQUIRED_VERSION)

try:
    import deluge.libtorrent as lt
    check_version(lt)
except ImportError:
    import libtorrent as lt
    check_version(lt)

==> deluge_1.3.6.orig.tar.gz: deluge-1.3.6/deluge/_libtorrent.py <==
#
# _libtorrent.py
#
# Copyright (C) 2009 Andrew Resch <andrewresch@gmail.com>
#
# Deluge is free software.
#
# You may redistribute it and/or modify it under the terms of the
# GNU General Public License, as published by the Free Software
# Foundation; either version 3 of the License, or (at your option)
# any later version.
#
# deluge is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with deluge.    If not, write to:
# 	The Free Software Foundation, Inc.,
# 	51 Franklin Street, Fifth Floor
# 	Boston, MA  02110-1301, USA.
#
#    In addition, as a special exception, the copyright holders give
#    permission to link the code of portions of this program with the OpenSSL
#    library.
#    You must obey the GNU General Public License in all respects for all of
#    the code used other than OpenSSL. If you modify file(s) with this
#    exception, you may extend this exception to your version of the file(s),
#    but you are not obligated to do so. If you do not wish to do so, delete
#    this exception statement from your version. If you delete this exception
#    statement from all source files in the program, then also delete it here.
#
#

"""
This module is used to handle the importing of libtorrent.

We use this module to control what versions of libtorrent this version of Deluge
supports.

** Usage **

>>> from deluge._libtorrent import lt

"""

REQUIRED_VERSION = "0.14.9.0"

def check_version(lt):
    from deluge.common import VersionSplit
    if VersionSplit(lt.version) < VersionSplit(REQUIRED_VERSION):
        raise ImportError("This version of Deluge requires libtorrent >=%s!" % REQUIRED_VERSION)

try:
    import deluge.libtorrent as lt
    check_version(lt)
except ImportError:
    import libtorrent as lt
    check_version(lt)
